==> spirit_hub-0.1.1.25.tar.gz: spirit_hub-0.1.1.25/spec/helpers/spirit_hub/user_display_options_spec.rb <==
# frozen_string_literal: true

require 'rails_helper'

RSpec.describe SpiritHub::UserDisplayOptionHelper, type: :helper do
  let(:user) { create(:user) }
  let(:hidden_columns) { {} }
  let(:display_option) { user.display_option.reload }

  before do
    display_option.update(hidden_columns:)
  end

  describe '#initialize' do
    subject { described_class.new(user) }

    it 'sets the user' do
      expect(subject.user).to eq(user)
    end

    it 'sets the display_option by reloading it' do
      expect(subject.display_option).to eq(display_option)
    end
  end

  describe '#get_columns_for' do
    subject { described_class.new(user) }

    context 'when no hidden columns are configured' do
      let(:hidden_columns) { {} }

      context 'for a controller with a defined column set' do
        it "returns the full columns, visible column keys and visible columns for 'search'" do
          all_columns, visible_keys, visible_columns = subject.get_columns_for('search')

          expect(all_columns).to eq(described_class::DEFAULT_COLUMNS)
          expect(visible_keys).to eq(described_class::DEFAULT_COLUMNS.keys)
          expect(visible_columns).to eq(described_class::DEFAULT_COLUMNS)
        end
      end

      context 'for a controller that is not explicitly defined' do
        it 'falls back to the DEFAULT_COLUMNS' do
          all_columns, visible_keys, visible_columns = subject.get_columns_for('non_existent_controller')

          expect(all_columns).to eq(described_class::DEFAULT_COLUMNS)
          expect(visible_keys).to eq(described_class::DEFAULT_COLUMNS.keys)
          expect(visible_columns).to eq(described_class::DEFAULT_COLUMNS)
        end
      end
    end

    context 'when there are hidden columns' do
      let(:hidden_columns) do
        { 'search' => %w[type updated_at] }
      end

      it 'excludes the hidden columns from the visible columns' do
        all_columns, visible_keys, visible_columns = subject.get_columns_for('search')

        expected_keys = described_class::DEFAULT_COLUMNS.keys - %i[type updated_at]

        expect(all_columns).to eq(described_class::DEFAULT_COLUMNS)
        expect(visible_keys).to eq(expected_keys)
        expect(visible_columns).not_to have_key(:type)
        expect(visible_columns).not_to have_key(:updated_at)
      end
    end

    context 'when testing a different controller configuration' do
      let(:hidden_columns) do
        { 'directories' => ['phase_title'] }
      end

      it "filters hidden columns for the 'directories' controller" do
        all_columns, visible_keys, visible_columns = subject.get_columns_for('directories')
        expected_all = described_class::DIRECTORIES_COLUMNS
        expected_keys = described_class::DIRECTORIES_COLUMNS.keys - [:phase_title]

        expect(all_columns).to eq(expected_all)
        expect(visible_keys).to eq(expected_keys)
        expect(visible_columns).not_to have_key(:phase_title)
      end
    end
  end
end

==> spirit_hub-1.0.0.5.tar.gz: spirit_hub-1.0.0.5/spec/helpers/spirit_hub/user_display_options_spec.rb <==
# frozen_string_literal: true

require 'rails_helper'

RSpec.describe SpiritHub::UserDisplayOptionHelper, type: :helper do
  let(:user) { create(:user) }
  let(:hidden_columns) { {} }
  let(:display_option) { user.display_option.reload }

  before do
    display_option.update(hidden_columns:)
  end

  describe '#get_columns_for' do
    subject { described_class }

    context 'when no hidden columns are configured' do
      let(:hidden_columns) { {} }

      context 'for a controller with a defined column set' do
        it "returns the full columns, visible column keys and visible columns for 'search'" do
          all_columns, visible_keys, visible_columns = subject.get_columns_for(user, 'search')

          expect(all_columns).to eq(described_class::DEFAULT_COLUMNS)
          expect(visible_keys).to eq(described_class::DEFAULT_COLUMNS.keys)
          expect(visible_columns).to eq(described_class::DEFAULT_COLUMNS)
        end
      end

      context 'for a controller that is not explicitly defined' do
        it 'falls back to the DEFAULT_COLUMNS' do
          all_columns, visible_keys, visible_columns = subject.get_columns_for(user, 'non_existent_controller')

          expect(all_columns).to eq(described_class::DEFAULT_COLUMNS)
          expect(visible_keys).to eq(described_class::DEFAULT_COLUMNS.keys)
          expect(visible_columns).to eq(described_class::DEFAULT_COLUMNS)
        end
      end
    end

    context 'when there are hidden columns' do
      let(:hidden_columns) do
        { 'search' => %w[type updated_at] }
      end

      it 'excludes the hidden columns from the visible columns' do
        all_columns, visible_keys, visible_columns = subject.get_columns_for(user, 'search')

        expected_keys = described_class::DEFAULT_COLUMNS.keys - %i[type updated_at]

        expect(all_columns).to eq(described_class::DEFAULT_COLUMNS)
        expect(visible_keys).to eq(expected_keys)
        expect(visible_columns).not_to have_key(:type)
        expect(visible_columns).not_to have_key(:updated_at)
      end
    end

    context 'when testing a different controller configuration' do
      let(:hidden_columns) do
        { 'directories' => ['phase_title'] }
      end

      it "filters hidden columns for the 'directories' controller" do
        all_columns, visible_keys, visible_columns = subject.get_columns_for(user, 'directories')
        expected_all = described_class::DIRECTORIES_COLUMNS
        expected_keys = described_class::DIRECTORIES_COLUMNS.keys - [:phase_title]

        expect(all_columns).to eq(expected_all)
        expect(visible_keys).to eq(expected_keys)
        expect(visible_columns).not_to have_key(:phase_title)
      end
    end
  end
end
